EscPosPrinter<T> class

Inheritance

Constructors

EscPosPrinter(PrinterConnector<T> connector, T model, {int dpi = 200, required int width, int beepCount = 4})

Properties

beepCount → int
final
connector ↔ PrinterConnector<T>
getter/setter pairinherited
dpi → int
final
hashCode → int
The hash code for this object.
no setterinherited
model ↔ T
getter/setter pairinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
width → int
final

Methods

beep() → Future<bool>
override
encodeSetIP(String ip) → List<int>
inherited
image(Uint8List image, {int threshold = 150}) → Future<bool>
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
pulseDrawer() → Future<bool>
override
selfTest() → Future<bool>
override
sendToConnector(List<int> fn(), {int? delayMs}) → Future<bool>
inherited
setIp(String ipAddress) → Future<bool>
override
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited